/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's 21 U.S.C.  851*
* Enhanced Drug Penalty Fiscal Year 2019 file and create a SAS dataset.                  *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\drug851fy19nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = drug851fy19nid ;

DATA library.&dataset ;
INFILE datafile LRECL=613;
INPUT
   USSCIDN  1-7             FILED  8-10              WITHDRWN  11-13       
   CTRELIEF  14-16          FILEDATE DATE11.         STMIN851  28-31       
   STMAX851  32-35          DGMIN851  36-39          DGMAX851  40-43       
   RELIEF  44-46            CRMHT851  47-49          INDTDATE DATE11.      
   PROFFN1  61-64           PROFFN2  65-68           PROFFN3  69-72        
   PROFFN4  73-76           PROFFN5  77-80           PROFFN6  81-84        
   PROFFN7  85-88           PROFFN8  89-92           PROFFN9  93-96        
   PROFFN10  97-100         PROFFN11  101-104        PROFFN12  105-108     
   PROFFN13  109-112        PROFFN14  113-116        PROFFN15  117-120     
   PROFFN16  121-124        PROFFN17  125-128        PROFFN18  129-132     
   PROFFN19  133-136        PROFFN20  137-140        PROFFN21  141-144     
   PROFFN22  145-148        PRSENT1  149-152         PRSENT2  153-156      
   PRSENT3  157-160         PRSENT4  161-164         PRSENT5  165-168      
   PRSENT6  169-172         PRSENT7  173-176         PRSENT8  177-180      
   PRSENT9  181-184         PRSENT10  185-188        PRSENT11  189-192     
   PRSENT12  193-196        PRSENT13  197-200        PRSENT14  201-204     
   PRSENT15  205-208        PRSENT16  209-212        PRSENT17  213-216     
   PRSENT18  217-220        PRSENT19  221-224        PRSENT20  225-228     
   PRSENT21  229-232        PRSENT22  233-236        PRSNDT1 DATE11.       
   PRSNDT2 DATE11.          PRSNDT3 DATE11.          PRSNDT4 DATE11.       
   PRSNDT5 DATE11.          PRSNDT6 DATE11.          PRSNDT7 DATE11.       
   PRSNDT8 DATE11.          PRSNDT9 DATE11.          PRSNDT10 DATE11.      
   PRSNDT11 DATE11.         PRSNDT12 DATE11.         PRSNDT13 DATE11.      
   PRSNDT14 DATE11.         PRSNDT15 DATE11.         PRSNDT16 DATE11.      
   PRSNDT17 DATE11.         PRSNDT18 DATE11.         PRSNDT19 DATE11.      
   PRSNDT20 DATE11.         PRSNDT21 DATE11.         PRSNDT22 DATE11.      
   OFFENNUM  479-481        PRCHPT1  482-484         PRCHPT2  485-487      
   PRCHPT3  488-490         PRCHPT4  491-493         PRCHPT5  494-496      
   PRCHPT6  497-499         PRCHPT7  500-502         PRCHPT8  503-505      
   PRCHPT9  506-508         PRCHPT10  509-511        PRCHPT11  512-514     
   PRCHPT12  515-517        PRCHPT13  518-520        PRCHPT14  521-523     
   PRCHPT15  524-526        PRCHPT16  527-529        PRCHPT17  530-532     
   PRCHPT18  533-535        PRCHPT19  536-538        PRCHPT20  539-541     
   PRCHPT21  542-544        PRCHPT22  545-547        PRFELN1  548-550      
   PRFELN2  551-553         PRFELN3  554-556         PRFELN4  557-559      
   PRFELN5  560-562         PRFELN6  563-565         PRFELN7  566-568      
   PRFELN8  569-571         PRFELN9  572-574         PRFELN10  575-577     
   PRFELN11  578-580        PRFELN12  581-583        PRFELN13  584-586     
   PRFELN14  587-589        PRFELN15  590-592        PRFELN16  593-595     
   PRFELN17  596-598        PRFELN18  599-601        PRFELN19  602-604     
   PRFELN20  605-607        PRFELN21  608-610        PRFELN22  611-613     
 ;                       

FORMAT
   FILEDATE DATE9.          INDTDATE DATE9.          PRSNDT1 DATE9.        
   PRSNDT2 DATE9.           PRSNDT3 DATE9.           PRSNDT4 DATE9.        
   PRSNDT5 DATE9.           PRSNDT6 DATE9.           PRSNDT7 DATE9.        
   PRSNDT8 DATE9.           PRSNDT9 DATE9.           PRSNDT10 DATE9.       
   PRSNDT11 DATE9.          PRSNDT12 DATE9.          PRSNDT13 DATE9.       
   PRSNDT14 DATE9.          PRSNDT15 DATE9.          PRSNDT16 DATE9.       
   PRSNDT17 DATE9.          PRSNDT18 DATE9.          PRSNDT19 DATE9.       
   PRSNDT20 DATE9.          PRSNDT21 DATE9.          PRSNDT22 DATE9.       
 ;
                      

LENGTH
   USSCIDN 6                FILED 3                  WITHDRWN 3            
   CTRELIEF 3               STMIN851 4               STMAX851 4            
   DGMIN851 4               DGMAX851 4               RELIEF 3              
   CRMHT851 3               PROFFN1 4                PROFFN2 4             
   PROFFN3 4                PROFFN4 4                PROFFN5 4             
   PROFFN6 4                PROFFN7 4                PROFFN8 4             
   PROFFN9 4                PROFFN10 4               PROFFN11 4            
   PROFFN12 4               PROFFN13 4               PROFFN14 4            
   PROFFN15 4               PROFFN16 4               PROFFN17 4            
   PROFFN18 4               PROFFN19 4               PROFFN20 4            
   PROFFN21 4               PROFFN22 4               PRSENT1 4             
   PRSENT2 4                PRSENT3 4                PRSENT4 4             
   PRSENT5 4                PRSENT6 4                PRSENT7 4             
   PRSENT8 4                PRSENT9 4                PRSENT10 4            
   PRSENT11 4               PRSENT12 4               PRSENT13 3            
   PRSENT14 3               PRSENT15 3               PRSENT16 3            
   PRSENT17 3               PRSENT18 3               PRSENT19 3            
   PRSENT20 3               PRSENT21 3               PRSENT22 3            
   OFFENNUM 3               PRCHPT1 3                PRCHPT2 3             
   PRCHPT3 3                PRCHPT4 3                PRCHPT5 3             
   PRCHPT6 3                PRCHPT7 3                PRCHPT8 3             
   PRCHPT9 3                PRCHPT10 3               PRCHPT11 3            
   PRCHPT12 3               PRCHPT13 3               PRCHPT14 3            
   PRCHPT15 3               PRCHPT16 3               PRCHPT17 3            
   PRCHPT18 3               PRCHPT19 3               PRCHPT20 3            
   PRCHPT21 3               PRCHPT22 3               PRFELN1 3             
   PRFELN2 3                PRFELN3 3                PRFELN4 3             
   PRFELN5 3                PRFELN6 3                PRFELN7 3             
   PRFELN8 3                PRFELN9 3                PRFELN10 3            
   PRFELN11 3               PRFELN12 3               PRFELN13 3            
   PRFELN14 3               PRFELN15 3               PRFELN16 3            
   PRFELN17 3               PRFELN18 3               PRFELN19 3            
   PRFELN20 3               PRFELN21 3               PRFELN22 3 ;

        

RUN ;
